@@ -1,7 +1,7 @@
 package App::wordlist;
 
-our $DATE = '2018-02-20'; # DATE
-our $VERSION = '0.264'; # VERSION
+our $DATE = '2018-03-19'; # DATE
+our $VERSION = '0.265'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,23 +37,16 @@ sub _length_in_graphemes {
 
 sub _list_installed {
     require Module::List;
-    my $mods1 = Module::List::list_modules(
+    my $mods = Module::List::list_modules(
         "WordList::",
         {
             list_modules  => 1,
             list_pod      => 0,
             recurse       => 1,
         });
-    my $mods2 = Module::List::list_modules(
-        "WordListC::",
-        {
-            list_modules  => 1,
-            list_pod      => 0,
-            recurse       => 1,
-        });
     my @res;
-    for my $wl0 ((sort keys %$mods1), (sort keys %$mods2)) {
-        (my $wl = $wl0) =~ s/\AWordListC?:://;
+    for my $wl0 (sort keys %$mods) {
+        (my $wl = $wl0) =~ s/\AWordList:://;
 
         my $type;
         if ($wl =~ /^(Base|MetaSyntactic)\z/) {
@@ -356,9 +349,6 @@ sub wordlist {
                 $mod = "WordList::$wl";
                 ($modpm = $mod . ".pm") =~ s!::!/!g;
                 last if eval { require $modpm; 1 };
-                $mod = "WordListC::$wl";
-                ($modpm = $mod . ".pm") =~ s!::!/!g;
-                last if eval { require $modpm; 1 };
                 die;
             }
             my $obj = $mod->new;
@@ -484,7 +474,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.264 of App::wordlist (from Perl distribution App-wordlist), released on 2018-02-20.
+This document describes version 0.265 of App::wordlist (from Perl distribution App-wordlist), released on 2018-03-19.
 
 =head1 SYNOPSIS
 
@@ -654,8 +644,6 @@ C<Games::Word::Wordlist::*> instead.
 
 L<WordList> and C<WordList::*> modules.
 
-L<WordListC> and C<WordListC::*> modules.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
